@@ -5,14 +5,15 @@ from torch import Tensor
 
 from pfhedge._utils.doc import set_attr_and_docstring
 from pfhedge._utils.doc import set_docstring
+from pfhedge._utils.str import _format_float
+from pfhedge.nn.functional import european_binary_payoff
 
-from ...nn.functional import european_binary_payoff
 from ..primary.base import Primary
+from .base import BaseOption
 from .base import Derivative
-from .base import OptionMixin
 
 
-class EuropeanBinaryOption(Derivative, OptionMixin):
+class EuropeanBinaryOption(BaseOption):
     """A European binary option.
 
     An American binary call option pays an unit amount of cash if and only if
@@ -51,10 +52,10 @@ class EuropeanBinaryOption(Derivative, OptionMixin):
         maturity (float, default=20/250) The maturity of the option.
         dtype (torch.dtype, optional): Desired device of returned tensor.
             Default: If None, uses a global default
-            (see ``torch.set_default_tensor_type()``).
+            (see :func:`torch.set_default_tensor_type()`).
         device (torch.device, optional): Desired device of returned tensor.
             Default: if None, uses the current device for the default tensor type
-            (see ``torch.set_default_tensor_type()``).
+            (see :func:`torch.set_default_tensor_type()`).
             ``device`` will be the CPU for CPU tensor types and
             the current CUDA device for CUDA tensor types.
 
@@ -96,14 +97,13 @@ class EuropeanBinaryOption(Derivative, OptionMixin):
 
         self.to(dtype=dtype, device=device)
 
-    def __repr__(self) -> str:
-        params = [f"{self.ul().__class__.__name__}(...)"]
+    def extra_repr(self) -> str:
+        params = []
         if not self.call:
-            params.append(f"call={self.call}")
-        params.append(f"strike={self.strike}")
-        params.append(f"maturity={self.maturity:.2e}")
-        params += self.dinfo
-        return self.__class__.__name__ + "(" + ", ".join(params) + ")"
+            params.append("call=" + str(self.call))
+        params.append("strike=" + _format_float(self.strike))
+        params.append("maturity=" + _format_float(self.maturity))
+        return ", ".join(params)
 
     def payoff(self) -> Tensor:
         return european_binary_payoff(
@@ -115,9 +115,10 @@ class EuropeanBinaryOption(Derivative, OptionMixin):
 set_attr_and_docstring(EuropeanBinaryOption, "simulate", Derivative.simulate)
 set_attr_and_docstring(EuropeanBinaryOption, "to", Derivative.to)
 set_attr_and_docstring(EuropeanBinaryOption, "ul", Derivative.ul)
+set_attr_and_docstring(EuropeanBinaryOption, "list", Derivative.list)
 set_docstring(EuropeanBinaryOption, "payoff", Derivative.payoff)
-set_attr_and_docstring(EuropeanBinaryOption, "moneyness", OptionMixin.moneyness)
-set_attr_and_docstring(EuropeanBinaryOption, "log_moneyness", OptionMixin.log_moneyness)
+set_attr_and_docstring(EuropeanBinaryOption, "moneyness", BaseOption.moneyness)
+set_attr_and_docstring(EuropeanBinaryOption, "log_moneyness", BaseOption.log_moneyness)
 set_attr_and_docstring(
-    EuropeanBinaryOption, "time_to_maturity", OptionMixin.time_to_maturity
+    EuropeanBinaryOption, "time_to_maturity", BaseOption.time_to_maturity
 )
