@@ -32,7 +32,7 @@ class Primary(Instrument):
     (See :class:`Derivative` for details).
 
     Buffers:
-        - ``spot`` (``torch.Tensor``): The spot price of the instrument.
+        - spot (:class:`torch.Tensor`): The spot price of the instrument.
 
     Attributes:
         dtype (torch.dtype): The dtype with which the simulated time-series are
@@ -40,11 +40,11 @@ class Primary(Instrument):
         device (torch.device): The device where the simulated time-series are.
     """
 
-    dtype: torch.dtype
-    device: torch.device
     dt: float
+    cost: float
     _buffers: Dict[str, Optional[Tensor]]
-    spot: Tensor
+    dtype: Optional[torch.dtype]
+    device: Optional[torch.device]
 
     def __init__(self) -> None:
         super().__init__()
@@ -90,8 +90,6 @@ class Primary(Instrument):
                 from this module using the given name
             tensor (Tensor or None): buffer to be registered. If ``None``, then
                 operations that run on buffers, such as :attr:`cuda`, are ignored.
-                If ``None``, the buffer is **not** included in the module's
-                :attr:`state_dict`.
         """
         # Implementation here refers to torch.nn.Module.register_buffer.
         if "_buffers" not in self.__dict__:
@@ -134,7 +132,7 @@ class Primary(Instrument):
         for _, buffer in self.named_buffers():
             yield buffer
 
-    def __getattr__(self, name: str) -> Union[Tensor, Module]:
+    def __getattr__(self, name: str) -> Tensor:
         if "_buffers" in self.__dict__:
             _buffers = self.__dict__["_buffers"]
             if name in _buffers:
@@ -143,13 +141,25 @@ class Primary(Instrument):
             "'{}' object has no attribute '{}'".format(type(self).__name__, name)
         )
 
+    @property
+    def spot(self) -> Tensor:
+        name = "spot"
+        if "_buffers" in self.__dict__:
+            _buffers = self.__dict__["_buffers"]
+            if name in _buffers:
+                return _buffers["spot"]
+        raise AttributeError(
+            f"'{self._get_name()}' object has no attribute '{name}'. "
+            "Asset may not be simulated."
+        )
+
     def to(self: T, *args, **kwargs) -> T:
         device, dtype, *_ = torch._C._nn._parse_to(*args, **kwargs)
 
         if dtype is not None and not dtype.is_floating_point:
             raise TypeError(
-                f"Instrument.to only accepts floating point "
-                f"dtypes, but got desired dtype={dtype}"
+                "Instrument.to only accepts floating point "
+                "dtypes, but got desired dtype=" + str(dtype)
             )
 
         if not hasattr(self, "dtype") or dtype is not None:
@@ -162,6 +172,15 @@ class Primary(Instrument):
 
         return self
 
+    def __repr__(self) -> str:
+        extra_repr = self.extra_repr()
+        dinfo = ", ".join(self._dinfo())
+        main_str = self._get_name() + "("
+        if extra_repr and dinfo:
+            extra_repr += ", "
+        main_str += extra_repr + dinfo + ")"
+        return main_str
+
 
 # Assign docstrings so they appear in Sphinx documentation
 set_docstring(Primary, "to", Instrument.to)
