@@ -107,8 +107,9 @@ class HestonStock(Primary):
     ) -> None:
         """Simulate the spot price and add it as a buffer named ``spot``.
 
-        The shape of the spot is :math:`(N, T)`, where :math:`N` is the number of
-        simulated paths and :math:`T` is the number of time steps.
+        The shape of the spot is :math:`(N, T)`, where
+        :math:`N` is the number of simulated paths and
+        :math:`T` is the number of time steps.
         The number of time steps is determinded from ``dt`` and ``time_horizon``.
 
         Args:
@@ -125,7 +126,7 @@ class HestonStock(Primary):
         if init_state is None:
             init_state = self.default_init_state
 
-        spot, variance = generate_heston(
+        output = generate_heston(
             n_paths=n_paths,
             n_steps=int(time_horizon / self.dt + 1),
             init_state=init_state,
@@ -138,8 +139,8 @@ class HestonStock(Primary):
             device=self.device,
         )
 
-        self.register_buffer("spot", spot)
-        self.register_buffer("variance", variance)
+        self.register_buffer("spot", output.spot)
+        self.register_buffer("variance", output.variance)
 
     def extra_repr(self) -> str:
         params = [
