@@ -3,6 +3,7 @@ from torch import Tensor
 
 from pfhedge._utils.bisect import bisect
 from pfhedge._utils.doc import set_attr_and_docstring
+from pfhedge._utils.str import _format_float
 
 from ._base import BSModuleMixin
 
@@ -15,9 +16,10 @@ class BSEuropeanOption(BSModuleMixin):
         strike (float, default=1.0): The strike price of the option.
 
     Shape:
-        - Input : :math:`(N, *, 3)`, where :math:`*` means any number
-          of additional dimensions. See ``inputs`` for the names of input features.
-        - Output: :math:`(N, *, 1)`. Delta of the derivative.
+        - Input: :math:`(N, *, 3)` where
+          :math:`*` means any number of additional dimensions.
+          See ``inputs`` for the names of input features.
+        - Output: :math:`(N, *, 1)`.
           All but the last dimension are the same shape as the input.
 
     .. seealso ::
@@ -33,7 +35,7 @@ class BSEuropeanOption(BSModuleMixin):
         >>>
         >>> m = BSEuropeanOption()
         >>> m.inputs()
-        ['log_moneyness', 'expiry_time', 'volatility']
+        ['log_moneyness', 'time_to_maturity', 'volatility']
         >>> input = torch.tensor([
         ...     [-0.01, 0.1, 0.2],
         ...     [ 0.00, 0.1, 0.2],
@@ -44,7 +46,7 @@ class BSEuropeanOption(BSModuleMixin):
                 [0.5752]])
 
     References:
-        John C. Hull, 2003. Options futures and other derivatives. Pearson.
+        - John C. Hull, 2003. Options futures and other derivatives. Pearson.
     """
 
     def __init__(self, call: bool = True, strike: float = 1.0):
@@ -71,38 +73,38 @@ class BSEuropeanOption(BSModuleMixin):
             >>> derivative = EuropeanOption(BrownianStock(), call=False)
             >>> m = BSEuropeanOption.from_derivative(derivative)
             >>> m
-            BSEuropeanOption(call=False)
+            BSEuropeanOption(call=False, strike=1.)
         """
         return cls(call=derivative.call, strike=derivative.strike)
 
     def extra_repr(self) -> str:
         params = []
         if not self.call:
-            params.append(f"call={self.call}")
-        if self.strike != 1.0:
-            params.append(f"strike={self.strike}")
+            params.append("call=" + str(self.call))
+        params.append("strike=" + _format_float(self.strike))
         return ", ".join(params)
 
     def delta(
-        self, log_moneyness: Tensor, expiry_time: Tensor, volatility: Tensor
+        self, log_moneyness: Tensor, time_to_maturity: Tensor, volatility: Tensor
     ) -> Tensor:
         """Returns delta of the derivative.
 
         Args:
             log_moneyness (torch.Tensor): Log moneyness of the underlying asset.
-            expiry_time (torch.Tensor): Time to expiry of the option.
+            time_to_maturity (torch.Tensor): Time to expiry of the option.
             volatility (torch.Tensor): Volatility of the underlying asset.
 
         Shape:
-            - log_moneyness: :math:`(N, *)`
-            - expiry_time: :math:`(N, *)`
+            - log_moneyness: :math:`(N, *)` where
+              :math:`*` means any number of additional dimensions.
+            - time_to_maturity: :math:`(N, *)`
             - volatility: :math:`(N, *)`
             - output: :math:`(N, *)`
 
         Returns:
             Tensor
         """
-        s, t, v = map(torch.as_tensor, (log_moneyness, expiry_time, volatility))
+        s, t, v = map(torch.as_tensor, (log_moneyness, time_to_maturity, volatility))
 
         delta = self.N.cdf(self.d1(s, t, v))
         delta = delta - 1 if not self.call else delta  # put-call parity
@@ -110,18 +112,19 @@ class BSEuropeanOption(BSModuleMixin):
         return delta
 
     def gamma(
-        self, log_moneyness: Tensor, expiry_time: Tensor, volatility: Tensor
+        self, log_moneyness: Tensor, time_to_maturity: Tensor, volatility: Tensor
     ) -> Tensor:
         """Returns gamma of the derivative.
 
         Args:
             log_moneyness: (torch.Tensor): Log moneyness of the underlying asset.
-            expiry_time (torch.Tensor): Time to expiry of the option.
+            time_to_maturity (torch.Tensor): Time to expiry of the option.
             volatility (torch.Tensor): Volatility of the underlying asset.
 
         Shape:
-            - log_moneyness: :math:`(N, *)`
-            - expiry_time: :math:`(N, *)`
+            - log_moneyness: :math:`(N, *)` where
+              :math:`*` means any number of additional dimensions.
+            - time_to_maturity: :math:`(N, *)`
             - volatility: :math:`(N, *)`
             - output: :math:`(N, *)`
 
@@ -133,32 +136,33 @@ class BSEuropeanOption(BSModuleMixin):
                 f"{self.__class__.__name__} for a put option is not yet supported."
             )
 
-        s, t, v = map(torch.as_tensor, (log_moneyness, expiry_time, volatility))
+        s, t, v = map(torch.as_tensor, (log_moneyness, time_to_maturity, volatility))
         price = self.strike * s.exp()
         gamma = self.N.log_prob(self.d1(s, t, v)).exp() / (price * v * t.sqrt())
 
         return gamma
 
     def price(
-        self, log_moneyness: Tensor, expiry_time: Tensor, volatility: Tensor
+        self, log_moneyness: Tensor, time_to_maturity: Tensor, volatility: Tensor
     ) -> Tensor:
         """Returns price of the derivative.
 
         Args:
             log_moneyness (torch.Tensor): Log moneyness of the underlying asset.
-            expiry_time (torch.Tensor): Time to expiry of the option.
+            time_to_maturity (torch.Tensor): Time to expiry of the option.
             volatility (torch.Tensor): Volatility of the underlying asset.
 
         Shape:
-            - log_moneyness: :math:`(N, *)`
-            - expiry_time: :math:`(N, *)`
+            - log_moneyness: :math:`(N, *)` where
+              :math:`*` means any number of additional dimensions.
+            - time_to_maturity: :math:`(N, *)`
             - volatility: :math:`(N, *)`
             - output: :math:`(N, *)`
 
         Returns:
             Tensor
         """
-        s, t, v = map(torch.as_tensor, (log_moneyness, expiry_time, volatility))
+        s, t, v = map(torch.as_tensor, (log_moneyness, time_to_maturity, volatility))
 
         n1 = self.N.cdf(self.d1(s, t, v))
         n2 = self.N.cdf(self.d2(s, t, v))
@@ -166,14 +170,14 @@ class BSEuropeanOption(BSModuleMixin):
         price = self.strike * (s.exp() * n1 - n2)
 
         if not self.call:
-            price += self.strike * (s.exp() - 1)  # put-call parity
+            price += self.strike * (1 - s.exp())  # put-call parity
 
         return price
 
     def implied_volatility(
         self,
         log_moneyness: Tensor,
-        expiry_time: Tensor,
+        time_to_maturity: Tensor,
         price: Tensor,
         precision: float = 1e-6,
     ) -> Tensor:
@@ -181,21 +185,22 @@ class BSEuropeanOption(BSModuleMixin):
 
         Args:
             log_moneyness (torch.Tensor): Log moneyness of the underlying asset.
-            expiry_time (torch.Tensor): Time to expiry of the option.
+            time_to_maturity (torch.Tensor): Time to expiry of the option.
             price (torch.Tensor): Price of the derivative.
             precision (float): Computational precision of the
                 implied volatility.
 
         Shape:
-            - log_moneyness: :math:`(N, *)`
-            - expiry_time: :math:`(N, *)`
+            - log_moneyness: :math:`(N, *)` where
+              :math:`*` means any number of additional dimensions.
+            - time_to_maturity: :math:`(N, *)`
             - price: :math:`(N, *)`
             - output: :math:`(N, *)`
 
         Returns
             Tensor
         """
-        s, t, p = map(torch.as_tensor, (log_moneyness, expiry_time, price))
+        s, t, p = map(torch.as_tensor, (log_moneyness, time_to_maturity, price))
         pricer = lambda v: self.price(s, t, v)
         return bisect(pricer, p, lower=0.001, upper=1.000, precision=precision)
 
