@@ -7,6 +7,7 @@ import pfhedge.autogreek as autogreek
 from pfhedge._utils.bisect import bisect
 from pfhedge._utils.doc import set_attr_and_docstring
 from pfhedge._utils.doc import set_docstring
+from pfhedge._utils.str import _format_float
 
 from ._base import BSModuleMixin
 
@@ -19,8 +20,9 @@ class BSEuropeanBinaryOption(BSModuleMixin):
         strike (float, default=1.0): The strike price of the option.
 
     Shape:
-        - Input: :math:`(N, *, 3)`, where :math:`*` means any number of additional
-          dimensions. See :func:`inputs` for the names of input features.
+        - Input: :math:`(N, *, 3)`, where
+          :math:`*` means any number of additional dimensions.
+          See :func:`inputs` for the names of input features.
         - Output: :math:`(N, *, 1)` Delta of the derivative.
           All but the last dimension are the same shape as the input.
 
@@ -37,7 +39,7 @@ class BSEuropeanBinaryOption(BSModuleMixin):
         >>>
         >>> m = BSEuropeanBinaryOption(strike=1.0)
         >>> m.inputs()
-        ['log_moneyness', 'expiry_time', 'volatility']
+        ['log_moneyness', 'time_to_maturity', 'volatility']
         >>> input = torch.tensor([
         ...     [-0.01, 0.1, 0.2],
         ...     [ 0.00, 0.1, 0.2],
@@ -80,39 +82,38 @@ class BSEuropeanBinaryOption(BSModuleMixin):
             >>> derivative = EuropeanBinaryOption(BrownianStock(), strike=1.1)
             >>> m = BSEuropeanBinaryOption.from_derivative(derivative)
             >>> m
-            BSEuropeanBinaryOption(strike=1.1)
+            BSEuropeanBinaryOption(strike=1.1000)
         """
         return cls(call=derivative.call, strike=derivative.strike)
 
     def extra_repr(self) -> str:
         params = []
-        if self.strike != 1.0:
-            params.append(f"strike={self.strike}")
+        params.append("strike=" + _format_float(self.strike))
         return ", ".join(params)
 
     def inputs(self) -> List[str]:
-        return ["log_moneyness", "expiry_time", "volatility"]
+        return ["log_moneyness", "time_to_maturity", "volatility"]
 
     def price(
-        self, log_moneyness: Tensor, expiry_time: Tensor, volatility: Tensor
+        self, log_moneyness: Tensor, time_to_maturity: Tensor, volatility: Tensor
     ) -> Tensor:
         """Returns price of the derivative.
 
         Args:
             log_moneyness (torch.Tensor): Log moneyness of the underlying asset.
-            expiry_time (torch.Tensor): Time to expiry of the option.
+            time_to_maturity (torch.Tensor): Time to expiry of the option.
             volatility (torch.Tensor): Volatility of the underlying asset.
 
         Shape:
             - log_moneyness: :math:`(N, *)`
-            - expiry_time: :math:`(N, *)`
+            - time_to_maturity: :math:`(N, *)`
             - volatility: :math:`(N, *)`
             - output: :math:`(N, *)`
 
         Returns:
             torch.Tensor
         """
-        s, t, v = map(torch.as_tensor, (log_moneyness, expiry_time, volatility))
+        s, t, v = map(torch.as_tensor, (log_moneyness, time_to_maturity, volatility))
 
         price = self.N.cdf(self.d2(s, t, v))
         price = 1.0 - price if not self.call else price  # put-call parity
@@ -121,25 +122,25 @@ class BSEuropeanBinaryOption(BSModuleMixin):
 
     @torch.enable_grad()
     def delta(
-        self, log_moneyness: Tensor, expiry_time: Tensor, volatility: Tensor
+        self, log_moneyness: Tensor, time_to_maturity: Tensor, volatility: Tensor
     ) -> Tensor:
         """Returns delta of the derivative.
 
         Args:
             log_moneyness: (torch.Tensor): Log moneyness of the underlying asset.
-            expiry_time (torch.Tensor): Time to expiry of the option.
+            time_to_maturity (torch.Tensor): Time to expiry of the option.
             volatility (torch.Tensor): Volatility of the underlying asset.
 
         Shape:
             - log_moneyness: :math:`(N, *)`
-            - expiry_time: :math:`(N, *)`
+            - time_to_maturity: :math:`(N, *)`
             - volatility: :math:`(N, *)`
             - output: :math:`(N, *)`
 
         Returns:
             torch.Tensor
         """
-        s, t, v = map(torch.as_tensor, (log_moneyness, expiry_time, volatility))
+        s, t, v = map(torch.as_tensor, (log_moneyness, time_to_maturity, volatility))
 
         delta = self.N.log_prob(self.d2(s, t, v)).exp() / (
             self.strike * s.exp() * v * t.sqrt()
@@ -147,18 +148,18 @@ class BSEuropeanBinaryOption(BSModuleMixin):
         return delta
 
     def gamma(
-        self, log_moneyness: Tensor, expiry_time: Tensor, volatility: Tensor
+        self, log_moneyness: Tensor, time_to_maturity: Tensor, volatility: Tensor
     ) -> Tensor:
         """Returns gamma of the derivative.
 
         Args:
             log_moneyness (torch.Tensor): Log moneyness of the underlying asset.
-            expiry_time (torch.Tensor): Time to expiry of the option.
+            time_to_maturity (torch.Tensor): Time to expiry of the option.
             volatility (torch.Tensor): Volatility of the underlying asset.
 
         Shape:
             - log_moneyness: :math:`(N, *)`
-            - expiry_time: :math:`(N, *)`
+            - time_to_maturity: :math:`(N, *)`
             - volatility: :math:`(N, *)`
             - output: :math:`(N, *)`
 
@@ -169,14 +170,14 @@ class BSEuropeanBinaryOption(BSModuleMixin):
             self.price,
             strike=self.strike,
             log_moneyness=log_moneyness,
-            expiry_time=expiry_time,
+            time_to_maturity=time_to_maturity,
             volatility=volatility,
         )
 
     def implied_volatility(
         self,
         log_moneyness: Tensor,
-        expiry_time: Tensor,
+        time_to_maturity: Tensor,
         price: Tensor,
         precision: float = 1e-6,
     ) -> Tensor:
@@ -184,19 +185,19 @@ class BSEuropeanBinaryOption(BSModuleMixin):
 
         Args:
             log_moneyness (torch.Tensor): Log moneyness of the underlying asset.
-            expiry_time (torch.Tensor): Time to expiry of the option.
+            time_to_maturity (torch.Tensor): Time to expiry of the option.
             price (torch.Tensor): Price of the derivative.
 
         Shape:
             - log_moneyness: :math:`(N, *)`
-            - expiry_time: :math:`(N, *)`
+            - time_to_maturity: :math:`(N, *)`
             - volatility: :math:`(N, *)`
             - output: :math:`(N, *)`
 
         Returns:
             torch.Tensor
         """
-        s, t, p = map(torch.as_tensor, (log_moneyness, expiry_time, price))
+        s, t, p = map(torch.as_tensor, (log_moneyness, time_to_maturity, price))
         pricer = lambda v: self.price(s, t, v)
         return bisect(pricer, p, lower=0.001, upper=1.000, precision=precision)
 
