@@ -3,6 +3,8 @@ from typing import Optional
 from torch import Tensor
 from torch.nn import Module
 
+from pfhedge._utils.str import _format_float
+
 from ..functional import clamp
 from ..functional import leaky_clamp
 
@@ -17,28 +19,36 @@ class LeakyClamp(Module):
     .. math ::
 
         \\text{output} = \\begin{cases}
-        \\min + \\text{clampled_slope} * (\\text{input} - \\min) &
-        \\text{input} < \\min \\\\
-        \\text{input} & \\min \\leq \\text{input} \\leq \\max \\\\
-        \\max + \\text{clampled_slope} * (\\text{input} - \\max) &
-        \\max < \\text{input}
+            \\min + \\text{clampled_slope} * (\\text{input} - \\min) &
+            \\text{input} < \\min \\\\
+            \\text{input} & \\min \\leq \\text{input} \\leq \\max \\\\
+            \\max + \\text{clampled_slope} * (\\text{input} - \\max) &
+            \\max < \\text{input}
         \\end{cases}
 
     If :math:`\\min > \\max`:
 
     .. math ::
 
-        \\text{output} = \\frac12 (\\min + \\max)
+        \\text{output} = \\begin{cases}
+            \\frac12 (\\min + \\max)
+            & \\text{inverted_output} = \\text{'mean'} \\\\
+            \\max
+            & \\text{inverted_output} = \\text{'max'} \\\\
+        \\end{cases}
 
     Args:
         clamped_slope (float, default=0.01):
             Controls the slope in the clampled regions.
+        inverted_output ({'mean', ''max'}, default='mean'):
+            Controls the output when :math:`\\min > \\max`.
+            'max' is consistent with :func:`torch.clamp`.
 
     Shape:
-        - input: :math:`(N, *)`, where :math:`*` means any number of additional
-          dimensions.
-        - min: :math:`(N, *)`
-        - max: :math:`(N, *)`
+        - input: :math:`(N, *)` where
+          :math:`*` means any number of additional dimensions.
+        - min: :math:`(N, *)` or any size broadcastable to ``input``.
+        - max: :math:`(N, *)` or any size broadcastable to ``input``.
         - output: :math:`(N, *)`, same shape as the input.
 
     Examples:
@@ -58,12 +68,17 @@ class LeakyClamp(Module):
                  8.0000e-01,  9.0000e-01,  1.0000e+00,  1.0010e+00,  1.0020e+00])
     """
 
-    def __init__(self, clamped_slope: float = 0.01):
+    def __init__(self, clamped_slope: float = 0.01, inverted_output: str = "mean"):
         super().__init__()
         self.clamped_slope = clamped_slope
+        self.inverted_output = inverted_output
 
     def extra_repr(self) -> str:
-        return f"clamped_slope={self.clamped_slope}" if self.clamped_slope != 0 else ""
+        return (
+            "clamped_slope=" + _format_float(self.clamped_slope)
+            if self.clamped_slope != 0
+            else ""
+        )
 
     def forward(
         self, input: Tensor, min: Optional[Tensor] = None, max: Optional[Tensor] = None
@@ -75,13 +90,6 @@ class LeakyClamp(Module):
             min (torch.Tensor, optional): Lower-bound of the range to be clamped to.
             max (torch.Tensor, optional): Upper-bound of the range to be clamped to.
 
-        Shape:
-            - input: :math:`(N, *)`, where :math:`*` means any number of additional
-              dimensions.
-            - min: :math:`(N, *)`
-            - max: :math:`(N, *)`
-            - output: :math:`(N, *)`, same shape as the input.
-
         Returns:
             torch.Tensor
         """
@@ -107,13 +115,23 @@ class Clamp(Module):
 
     .. math ::
 
-        \\text{output} = \\frac12 (\\min + \\max)
+        \\text{output} = \\begin{cases}
+            \\frac12 (\\min + \\max)
+            & \\text{inverted_output} = \\text{'mean'} \\\\
+            \\max
+            & \\text{inverted_output} = \\text{'max'} \\\\
+        \\end{cases}
+
+    Args:
+        inverted_output ({'mean', ''max'}, default='mean'):
+            Controls the output when :math:`\\min > \\max`.
+            'max' is consistent with :func:`torch.clamp`.
 
     Shape:
-        - input: :math:`(N, *)`, where :math:`*` means any number of additional
-          dimensions.
-        - min: :math:`(N, *)`
-        - max: :math:`(N, *)`
+        - input: :math:`(N, *)` where
+          :math:`*` means any number of additional dimensions.
+        - min: :math:`(N, *)` or any size broadcastable to ``input``.
+        - max: :math:`(N, *)` or any size broadcastable to ``input``.
         - output: :math:`(N, *)`, same shape as the input.
 
     Examples:
@@ -151,13 +169,6 @@ class Clamp(Module):
             min (torch.Tensor, optional): Lower-bound of the range to be clamped to.
             max (torch.Tensor, optional): Upper-bound of the range to be clamped to.
 
-        Shape:
-            - input: :math:`(N, *)`, where :math:`*` means any number of additional
-              dimensions.
-            - min: :math:`(N, *)`
-            - max: :math:`(N, *)`
-            - output: :math:`(N, *)`, same shape as the input.
-
         Returns:
             torch.Tensor
         """
