@@ -10,15 +10,17 @@ class Naked(Module):
         out_features (int, default=1): Size of each output sample.
 
     Shape:
-        - Input: :math:`(N, *, H_{\\text{in}})`, where where * means any number of
-          additional dimensions and :math:`H_{\\text{in}})` is the number of input
-          features.
-        - Output: :math:`(N, *, H_{\\text{out}})`, where all but the last dimension
-          are the same shape as the input and :math:`H_{\\text{in}})` is
-          `out_features`.
+        - Input: :math:`(N, *, H_{\\text{in}})` where
+          :math:`*` means any number of additional dimensions and
+          :math:`H_{\\text{in}}` is the number of input features.
+        - Output: :math:`(N, *, H_{\\text{out}})` where
+          all but the last dimension are the same shape as the input and
+          :math:`H_{\\text{out}}` is the number of output features.
 
     Examples:
 
+        >>> from pfhedge.nn import Naked
+        >>>
         >>> m = Naked()
         >>> input = torch.empty((2, 3))
         >>> m(input)
